summaryrefslogtreecommitdiffstats
path: root/src/lookup
diff options
context:
space:
mode:
authorPeng Wu <alexepico@gmail.com>2017-01-12 17:13:33 +0800
committerPeng Wu <alexepico@gmail.com>2017-01-12 17:13:33 +0800
commit7755dff83c109155e2d7eb1cf7411477138a5094 (patch)
treec09296d33da6607e2ff925e7577712f6f6e89c70 /src/lookup
parentab4b8afebf5eba07ebf41c680816ee3d7bcca160 (diff)
downloadlibpinyin-7755dff83c109155e2d7eb1cf7411477138a5094.tar.gz
libpinyin-7755dff83c109155e2d7eb1cf7411477138a5094.tar.xz
libpinyin-7755dff83c109155e2d7eb1cf7411477138a5094.zip
rename variables
Diffstat (limited to 'src/lookup')
-rw-r--r--src/lookup/phonetic_lookup.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/src/lookup/phonetic_lookup.h b/src/lookup/phonetic_lookup.h
index 59110e5..e82b07b 100644
--- a/src/lookup/phonetic_lookup.h
+++ b/src/lookup/phonetic_lookup.h
@@ -32,10 +32,10 @@ struct trellis_value_t {
// the character length of the final sentence.
gint32 m_sentence_length;
gfloat m_poss;
// the m_last_step and m_last_index points to this trellis.
gint32 m_last_step;
- // the m_last_index points to the last trellis_node.
- gint32 m_last_index;
+ // the m_sub_index points to the inside of last trellis_node.
+ gint32 m_sub_index;
// the current index in this trellis_node.
// only initialized in the get_candidates method.
gint32 m_current_index;
@@ -46,7 +46,7 @@ struct trellis_value_t {
m_sentence_length = 0;
m_poss = poss;
m_last_step = -1;
- m_last_index = -1;
+ m_sub_index = -1;
m_current_index = -1;
}
};
@@ -129,7 +129,7 @@ public:
bool get_tails(/* out */ GArray * tails) const;
/* get candidate */
bool get_candidate(gint32 index, phrase_token_t token,
- gint32 last_index, trellis_value_t * candidate) const;
+ gint32 sub_index, trellis_value_t * candidate) const;
};
template <gint32 nbest>
@@ -32,10 +32,10 @@ struct trellis_value_t {
gint32 m_sentence_length;
gfloat m_poss;
- // the m_last_step and m_last_index points to this trellis.
+ // the m_last_step and m_sub_index points to this trellis.
gint32 m_last_step;